# openrelik-common
Common utilities for OpenRelik 

# Documentation
Documentation can be found [here](https://openrelik.github.io/openrelik-common/openrelik_common/index.html)

# Run Tests
```
poetry install --with test --no-root
poetry run pytest --cov=.
```

##### Obligatory Fine Print
This is not an official Google product (experimental or otherwise), it is just code that happens to be owned by Google.
